@@ -3,41 +3,29 @@
 #
 # Fill in `templates'
 #
-# Copyright 1996, 1997, 1999, 2001, 2002, 2003, 2005 M-J. Dominus.
+# Copyright 2013 M. J. Dominus.
 # You may copy and distribute this program under the
-# same terms as Perl iteself.
+# same terms as Perl itself.  
 # If in doubt, write to mjd-perl-template+@plover.com for a license.
 #
-# Version 1.45
 
 package Text::Template;
+$Text::Template::VERSION = '1.47';
+# ABSTRACT: Expand template text with embedded Perl
+
 require 5.004;
 use Exporter;
 @ISA = qw(Exporter);
-@EXPORT_OK = qw(
-  fill_in_file
-  fill_in_string
-  TTerror
-);
+@EXPORT_OK = qw(fill_in_file fill_in_string TTerror);
 use vars '$ERROR';
 use strict;
 
-$Text::Template::VERSION = '1.45';
 my %GLOBAL_PREPEND = ('Text::Template' => '');
 
 sub Version {
   $Text::Template::VERSION;
 }
 
-# _param():  Internal subroutine called within new(), fill_in() and 
-# fill_in_string()
-# used to set various parameters within caller.  Written so as to account for
-# variations in the case of arguments passed to caller.
-# Arguments:
-# 1.  scalar
-# 2.  hash or list of key-value pairs
-# Return value:  Appropriate parameter
-
 sub _param {
   my $kk;
   my ($k, %h) = @_;
@@ -47,14 +35,6 @@ sub _param {
   return;
 }
 
-# always_prepend():  Text::Template class method which prepends Perl code 
-# passed as argument to each template fragment.
-# Argument:
-# 1.  string containing Perl code
-# Returns:
-# Last string containing Perl code used for prepending, if any; 
-# otherwise, empty string
-
 sub always_prepend
 {
   my $pack = shift;
@@ -63,17 +43,15 @@ sub always_prepend
   $old;
 }
 
-# new():  Text::Template constructor
-
 {
   my %LEGAL_TYPE;
-  BEGIN {
+  BEGIN { 
     %LEGAL_TYPE = map {$_=>1} qw(FILE FILEHANDLE STRING ARRAY);
   }
   sub new {
     my $pack = shift;
     my %a = @_;
-    my $stype = uc(_param('type', %a)) || 'FILE';
+    my $stype = uc(_param('type', %a) || "FILE");
     my $source = _param('source', %a);
     my $untaint = _param('untaint', %a);
     my $prepend = _param('prepend', %a);
@@ -87,13 +65,12 @@ sub always_prepend
       require Carp;
       Carp::croak("Illegal value `$stype' for TYPE parameter");
     }
-    my $self = {
-      TYPE    => $stype,
-      PREPEND => $prepend,
-      UNTAINT => $untaint,
-      BROKEN  => $broken,
-      (defined $alt_delim ? (DELIM => $alt_delim) : ()),
-    };
+    my $self = {TYPE => $stype,
+		PREPEND => $prepend,
+                UNTAINT => $untaint,
+                BROKEN => $broken,
+		(defined $alt_delim ? (DELIM => $alt_delim) : ()),
+	       };
     # Under 5.005_03, if any of $stype, $prepend, $untaint, or $broken
     # are tainted, all the others become tainted too as a result of
     # sharing the expression with them.  We install $source separately
@@ -102,24 +79,18 @@ sub always_prepend
 
     bless $self => $pack;
     return unless $self->_acquire_data;
-
+    
     $self;
   }
 }
 
-# _acquire_data(): Internal subroutine which may be called in the 
-# following locations:
-# toward end of new()
-# in source()
-# in compile()
 # Convert template objects of various types to type STRING,
 # in which the template data is embedded in the object itself.
-
 sub _acquire_data {
   my ($self) = @_;
   my $type = $self->{TYPE};
   if ($type eq 'STRING') {
-    # nothing necessary
+    # nothing necessary    
   } elsif ($type eq 'FILE') {
     my $data = _load_text($self->{SOURCE});
     unless (defined $data) {
@@ -145,7 +116,7 @@ sub _acquire_data {
     }
     $self->{SOURCE} = $data;
   } else {
-    # This should have been caught long ago, so it represents a
+    # This should have been caught long ago, so it represents a 
     # drastic `can't-happen' sort of failure
     my $pack = ref $self;
     die "Can only acquire data for $pack objects of subtype STRING, but this is $type; aborting";
@@ -153,16 +124,12 @@ sub _acquire_data {
   $self->{DATA_ACQUIRED} = 1;
 }
 
-# source():  Called only within Text::Template::Preprocess::fill_in()
-
 sub source {
   my ($self) = @_;
   $self->_acquire_data unless $self->{DATA_ACQUIRED};
   return $self->{SOURCE};
 }
 
-# set_source_data():  Called only within Text::Template::Preprocess::fill_in()
-
 sub set_source_data {
   my ($self, $newdata) = @_;
   $self->{SOURCE} = $newdata;
@@ -171,10 +138,6 @@ sub set_source_data {
   1;
 }
 
-# compile():  See MJD's documentation in POD.
-# While it's a publicly callable method, it's usually called internally
-# within fill_in() or fill_in_file().
-
 sub compile {
   my $self = shift;
 
@@ -183,15 +146,18 @@ sub compile {
   return undef unless $self->_acquire_data;
   unless ($self->{TYPE} eq 'STRING') {
     my $pack = ref $self;
-    # This should have been caught long ago, so it represents a
+    # This should have been caught long ago, so it represents a 
     # drastic `can't-happen' sort of failure
     die "Can only compile $pack objects of subtype STRING, but this is $self->{TYPE}; aborting";
   }
 
   my @tokens;
   my $delim_pats = shift() || $self->{DELIM};
+
+  
+
   my ($t_open, $t_close) = ('{', '}');
-  my $DELIM;      # Regex matches a delimiter if $delim_pats
+  my $DELIM;			# Regex matches a delimiter if $delim_pats
   if (defined $delim_pats) {
     ($t_open, $t_close) = @$delim_pats;
     $DELIM = "(?:(?:\Q$t_open\E)|(?:\Q$t_close\E))";
@@ -208,36 +174,36 @@ sub compile {
   while (@tokens) {
     my $t = shift @tokens;
     next if $t eq '';
-    if ($t eq $t_open) {  # Brace or other opening delimiter
+    if ($t eq $t_open) {	# Brace or other opening delimiter
       if ($depth == 0) {
-        push @content, [$state, $cur_item, $lineno] if $cur_item ne '';
-        $cur_item = '';
-        $state = 'PROG';
-        $prog_start = $lineno;
+	push @content, [$state, $cur_item, $lineno] if $cur_item ne '';
+	$cur_item = '';
+	$state = 'PROG';
+	$prog_start = $lineno;
       } else {
-        $cur_item .= $t;
+	$cur_item .= $t;
       }
       $depth++;
-    } elsif ($t eq $t_close) {  # Brace or other closing delimiter
+    } elsif ($t eq $t_close) {	# Brace or other closing delimiter
       $depth--;
       if ($depth < 0) {
-        $ERROR = "Unmatched close brace at line $lineno";
-        return undef;
+	$ERROR = "Unmatched close brace at line $lineno";
+	return undef;
       } elsif ($depth == 0) {
-        push @content, [$state, $cur_item, $prog_start] if $cur_item ne '';
-        $state = 'TEXT';
-        $cur_item = '';
+	push @content, [$state, $cur_item, $prog_start] if $cur_item ne '';
+	$state = 'TEXT';
+	$cur_item = '';
       } else {
-        $cur_item .= $t;
+	$cur_item .= $t;
       }
     } elsif (!$delim_pats && $t eq '\\\\') { # precedes \\\..\\\{ or \\\..\\\}
       $cur_item .= '\\';
     } elsif (!$delim_pats && $t =~ /^\\([{}])$/) { # Escaped (literal) brace?
-      $cur_item .= $1;
-    } elsif ($t eq "\n") {  # Newline
+	$cur_item .= $1;
+    } elsif ($t eq "\n") {	# Newline
       $lineno++;
       $cur_item .= $t;
-    } else {      # Anything else
+    } else {			# Anything else
       $cur_item .= $t;
     }
   }
@@ -250,16 +216,12 @@ sub compile {
   } else {
     die "Can't happen error #1";
   }
-
+  
   $self->{TYPE} = 'PREPARSED';
   $self->{SOURCE} = \@content;
   1;
 }
 
-# prepend_text(): 
-# Used when deriving classes from Text::Template to prepend code
-# at fill_in time.
-
 sub prepend_text {
   my ($self) = @_;
   my $t = $self->{PREPEND};
@@ -273,10 +235,6 @@ sub prepend_text {
   return $t;
 }
 
-# fill_in()
-# Publicly callable method to fill in templates.
-# Extensively documented in POD.
-
 sub fill_in {
   my $fi_self = shift;
   my %fi_a = @_;
@@ -290,14 +248,14 @@ sub fill_in {
 
   my $fi_varhash = _param('hash', %fi_a);
   my $fi_package = _param('package', %fi_a) ;
-  my $fi_broken  =
+  my $fi_broken  = 
     _param('broken', %fi_a)  || $fi_self->{BROKEN} || \&_default_broken;
   my $fi_broken_arg = _param('broken_arg', %fi_a) || [];
   my $fi_safe = _param('safe', %fi_a);
   my $fi_ofh = _param('output', %fi_a);
   my $fi_eval_package;
   my $fi_scrub_package = 0;
-  my $fi_filename = $fi_self->{FILENAME} || 'template';
+  my $fi_filename = _param('filename') || $fi_self->{FILENAME} || 'template';
 
   my $fi_prepend = _param('prepend', %fi_a);
   unless (defined $fi_prepend) {
@@ -339,29 +297,30 @@ sub fill_in {
   foreach $fi_item (@{$fi_self->{SOURCE}}) {
     my ($fi_type, $fi_text, $fi_lineno) = @$fi_item;
     if ($fi_type eq 'TEXT') {
-      if ($fi_ofh) {
-        print $fi_ofh $fi_text;
-      } else {
-        $fi_r .= $fi_text;
-      }
+      $fi_self->append_text_to_output(
+        text   => $fi_text,
+        handle => $fi_ofh,
+        out    => \$fi_r,
+        type   => $fi_type,
+      );
     } elsif ($fi_type eq 'PROG') {
       no strict;
       my $fi_lcomment = "#line $fi_lineno $fi_filename";
-      my $fi_progtext =
+      my $fi_progtext = 
         "package $fi_eval_package; $fi_prepend;\n$fi_lcomment\n$fi_text;";
       my $fi_res;
       my $fi_eval_err = '';
       if ($fi_safe) {
         $fi_safe->reval(q{undef $OUT});
-        $fi_res = $fi_safe->reval($fi_progtext);
-        $fi_eval_err = $@;
-        my $OUT = $fi_safe->reval('$OUT');
-        $fi_res = $OUT if defined $OUT;
+	$fi_res = $fi_safe->reval($fi_progtext);
+	$fi_eval_err = $@;
+	my $OUT = $fi_safe->reval('$OUT');
+	$fi_res = $OUT if defined $OUT;
       } else {
-        my $OUT;
-        $fi_res = eval $fi_progtext;
-        $fi_eval_err = $@;
-        $fi_res = $OUT if defined $OUT;
+	my $OUT;
+	$fi_res = eval $fi_progtext;
+	$fi_eval_err = $@;
+	$fi_res = $OUT if defined $OUT;
       }
 
       # If the value of the filled-in text really was undef,
@@ -370,27 +329,28 @@ sub fill_in {
       $fi_res = '' unless defined $fi_res;
 
       if ($fi_eval_err) {
-        $fi_res = $fi_broken->(
-          text   => $fi_text,
-          error  => $fi_eval_err,
-          lineno => $fi_lineno,
-          arg    => $fi_broken_arg,
-        );
-        if (defined $fi_res) {
-          if (defined $fi_ofh) {
-            print $fi_ofh $fi_res;
-          } else {
-            $fi_r .= $fi_res;
-          }
-        } else {
-          return $fi_res;    # Undefined means abort processing
-        }
+	$fi_res = $fi_broken->(text => $fi_text,
+			       error => $fi_eval_err,
+			       lineno => $fi_lineno,
+			       arg => $fi_broken_arg,
+			       );
+	if (defined $fi_res) {
+          $fi_self->append_text_to_output(
+            text   => $fi_res,
+            handle => $fi_ofh,
+            out    => \$fi_r,
+            type   => $fi_type,
+          );
+	} else {
+	  return $fi_res;		# Undefined means abort processing
+	}
       } else {
-        if (defined $fi_ofh) {
-          print $fi_ofh $fi_res;
-        } else {
-          $fi_r .= $fi_res;
-        }
+        $fi_self->append_text_to_output(
+          text   => $fi_res,
+          handle => $fi_ofh,
+          out    => \$fi_r,
+          type   => $fi_type,
+        );
       }
     } else {
       die "Can't happen error #2";
@@ -401,22 +361,34 @@ sub fill_in {
   defined $fi_ofh ? 1 : $fi_r;
 }
 
-# fill_in_string:
-# Publicly callable method; see documentation in POD.
+sub append_text_to_output {
+  my ($self, %arg) = @_;
 
-sub fill_in_string {
-  my $string = shift;
-  my $package = _param('package', @_);
-  push @_, 'package' => scalar(caller) unless defined $package;
-  my $templ = Text::Template->new(TYPE => 'STRING', SOURCE => $string, @_)
+  if (defined $arg{handle}) {
+    print { $arg{handle} } $arg{text};
+  } else {
+    ${ $arg{out} } .= $arg{text};
+  }
+
+  return;
+}
+
+sub fill_this_in {
+  my $pack = shift;
+  my $text = shift;
+  my $templ = $pack->new(TYPE => 'STRING', SOURCE => $text, @_)
     or return undef;
   $templ->compile or return undef;
   my $result = $templ->fill_in(@_);
   $result;
 }
 
-# fill_in_file:
-# Publicly callable method; see documentation in POD.
+sub fill_in_string {
+  my $string = shift;
+  my $package = _param('package', @_);
+  push @_, 'package' => scalar(caller) unless defined $package;
+  Text::Template->fill_this_in($string, @_);
+}
 
 sub fill_in_file {
   my $fn = shift;
@@ -429,8 +401,11 @@ sub fill_in_file {
 
 sub _default_broken {
   my %a = @_;
+  my $prog_text = $a{text};
   my $err = $a{error};
+  my $lineno = $a{lineno};
   chomp $err;
+#  $err =~ s/\s+at .*//s;
   "Program fragment delivered error ``$err''";
 }
 
@@ -469,14 +444,14 @@ sub _unconditionally_untaint {
     foreach my $key (keys %$hash) {
       undef $hash->{$key};
     }
+    %$hash = ();
+    delete $Text::Template::{$s."::"};
   }
 }
-
-# _install_hash():  Internal subroutine called within fill_in().
+  
 # Given a hashful of variables (or a list of such hashes)
 # install the variables into the specified package,
 # overwriting whatever variables were there before.
-
 sub _install_hash {
   my $hashlist = shift;
   my $dest = shift;
@@ -491,11 +466,11 @@ sub _install_hash {
       no strict 'refs';
       local *SYM = *{"$ {dest}::$name"};
       if (! defined $val) {
-        delete ${"$ {dest}::"}{$name};
+	delete ${"$ {dest}::"}{$name};
       } elsif (ref $val) {
-        *SYM = $val;
+	*SYM = $val;
       } else {
-        *SYM = \$val;
+ 	*SYM = \$val;
       }
     }
   }
@@ -505,6 +480,9 @@ sub TTerror { $ERROR }
 
 1;
 
+__END__
+
+=pod
 
 =head1 NAME
 
@@ -512,7 +490,7 @@ Text::Template - Expand template text with embedded Perl
 
 =head1 VERSION
 
-This file documents C<Text::Template> version B<1.45>
+version 1.47
 
 =head1 SYNOPSIS
 
@@ -567,7 +545,7 @@ This file documents C<Text::Template> version B<1.45>
  $text = fill_in_string( <<EOM, PACKAGE => 'T', ...);
  Dear {$recipient},
  Pay me at once.
-        Love,
+        Love, 
          G.V.
  EOM
 
@@ -583,7 +561,7 @@ This is a library for generating form letters, building HTML pages, or
 filling in templates generally.  A `template' is a piece of text that
 has little Perl programs embedded in it here and there.  When you
 `fill in' a template, you evaluate the little programs and replace
-them with their values.
+them with their values.  
 
 You can store a template in a file outside your program.  People can
 modify the template without modifying the program.  You can separate
@@ -607,7 +585,6 @@ file C<formletter.tmpl>:
 
 			Mark "Vizopteryx" Dominus
 
-
 The result of filling in this template is a string, which might look
 something like this:
 
@@ -646,7 +623,6 @@ template into the example result, and prints it out:
 	if (defined $result) { print $result }
 	else { die "Couldn't fill in template: $Text::Template::ERROR" }
 
-
 =head2 Philosophy
 
 When people make a template module like this one, they almost always
@@ -703,7 +679,7 @@ C<DELIMITERS> option.  (See L<"Alternative Delimiters">, below.)
 
 Each program fragment should be a sequence of Perl statements, which
 are evaluated the usual way.  The result of the last statement
-executed will be evaluted in scalar context; the result of this
+executed will be evaluated in scalar context; the result of this
 statement is a string, which is interpolated into the template in
 place of the program fragment itself.
 
@@ -711,16 +687,16 @@ The fragments are evaluated in order, and side effects from earlier
 fragments will persist into later fragments:
 
 	{$x = @things; ''}The Lord High Chamberlain has gotten {$x}
-	things for me this year.
-	{ $diff = $x - 17;
+	things for me this year.  
+	{ $diff = $x - 17; 
 	  $more = 'more'
 	  if ($diff == 0) {
 	    $diff = 'no';
 	  } elsif ($diff < 0) {
 	    $more = 'fewer';
-	  }
+	  } 
           '';
-	}
+	} 
 	That is {$diff} {$more} than he gave me last year.
 
 The value of C<$x> set in the first line will persist into the next
@@ -729,11 +705,11 @@ C<$more> set in the second fragment will persist and be interpolated
 into the last line.  The output will look something like this:
 
 	The Lord High Chamberlain has gotten 42
-	things for me this year.
+	things for me this year.  
 
 	That is 25 more than he gave me last year.
 
-That is all the syntax there is.
+That is all the syntax there is.  
 
 =head2 The C<$OUT> variable
 
@@ -754,9 +730,9 @@ One way to do it is with a template like this:
 	{ my $blist = '';
           foreach $i (@items) {
             $blist .= qq{  * $i\n};
-          }
+          }    
           $blist;
-        }
+        } 
 
 Here we construct the list in a variable called C<$blist>, which we
 return at the end.  This is a little cumbersome.  There is a shortcut.
@@ -771,11 +747,11 @@ This means that you can write the template above like this:
 	Here is a list of the things I have got for you since 1907:
 	{ foreach $i (@items) {
             $OUT .= "  * $i\n";
-          }
-        }
+          }    
+        } 
 
 C<$OUT> is reinitialized to the empty string at the start of each
-program fragment.  It is private to C<Text::Template>, so
+program fragment.  It is private to C<Text::Template>, so 
 you can't use a variable named C<$OUT> in your template without
 invoking the special behavior.
 
@@ -808,15 +784,15 @@ else that makes sense with C<open>.
 The C<TYPE> can also be C<STRING>, in which case the C<SOURCE> should
 be a string:
 
-	new Text::Template ( TYPE => 'STRING',
+	new Text::Template ( TYPE => 'STRING', 
                              SOURCE => "This is the actual template!" );
 
 The C<TYPE> can be C<ARRAY>, in which case the source should be a
 reference to an array of strings.  The concatenation of these strings
 is the template:
 
-	new Text::Template ( TYPE => 'ARRAY',
-                             SOURCE => [ "This is ", "the actual",
+	new Text::Template ( TYPE => 'ARRAY', 
+                             SOURCE => [ "This is ", "the actual", 
                                          " template!",
                                        ]
                            );
@@ -828,10 +804,9 @@ C<Text::Template> will read the text from the filehandle up to
 end-of-file, and that text is the template:
 
 	# Read template source code from STDIN:
-	new Text::Template ( TYPE => 'FILEHANDLE',
+	new Text::Template ( TYPE => 'FILEHANDLE', 
                              SOURCE => \*STDIN  );
 
-
 If you omit the C<TYPE> attribute, it's taken to be C<FILE>.
 C<SOURCE> is required.  If you omit it, the program will abort.
 
@@ -898,7 +873,7 @@ overridden in the arguments to C<fill_in>.  See L<C<BROKEN>> below.
 Loads all the template text from the template's source, parses and
 compiles it.  If successful, returns true; otherwise returns false and
 sets C<$Text::Template::ERROR>.  If the template is already compiled,
-it returns true and does nothing.
+it returns true and does nothing.  
 
 You don't usually need to invoke this function, because C<fill_in>
 (see below) compiles the template if it isn't compiled already.
@@ -929,8 +904,7 @@ may yield spurious warnings about
 so you might like to avoid them and use the capitalized versions.
 
 At present, there are eight legal options:  C<PACKAGE>, C<BROKEN>,
-C<BROKEN_ARG>, C<SAFE>, C<HASH>, C<OUTPUT>, C<DELIMITERS> and 
-<PREPEND>.
+C<BROKEN_ARG>, C<SAFE>, C<HASH>, C<OUTPUT>, and C<DELIMITERS>.
 
 =over 4
 
@@ -973,7 +947,6 @@ Here's an example of using C<PACKAGE>:
 We want to pass in an array which will be assigned to the array
 C<@items>.  Here's how to do that:
 
-
 	@items = ('ivory', 'apes', 'peacocks', );
 	$template->fill_in();
 
@@ -1006,10 +979,10 @@ variables.
 
 You may not want to put the template variables into a package.
 Packages can be hard to manage:  You can't copy them, for example.
-C<HASH> provides an alternative.
+C<HASH> provides an alternative.  
 
 The value for C<HASH> should be a reference to a hash that maps
-variable names to values.  For example,
+variable names to values.  For example, 
 
 	$template->fill_in(HASH => { recipient => "The King",
 				     items => ['gold', 'frankincense', 'myrrh'],
@@ -1025,19 +998,19 @@ should be passed by reference.
 We also want to pass an object, which is in C<$self>; note that we
 pass a reference to the object, C<\$self> instead.  Since we've passed
 a reference to a scalar, inside the template the object appears as
-C<$object>.
+C<$object>.  
 
 The full details of how it works are a little involved, so you might
 want to skip to the next section.
 
-Suppose the key in the hash is I<key> and the value is I<value>.
+Suppose the key in the hash is I<key> and the value is I<value>.  
 
 =over 4
 
 =item *
 
 If the I<value> is C<undef>, then any variables named C<$key>,
-C<@key>, C<%key>, etc., are undefined.
+C<@key>, C<%key>, etc., are undefined.  
 
 =item *
 
@@ -1061,7 +1034,7 @@ and
 
 have almost exactly the same effect.  (The difference is that in the
 former case, the value is copied, and in the latter case it is
-aliased.)
+aliased.)  
 
 =item *
 
@@ -1103,7 +1076,7 @@ You can also use this to set two variables with the same name:
 	                           ]
                           );
 
-This sets C<$v> to C<"The King"> and C<@v> to C<(1,2,3)>.
+This sets C<$v> to C<"The King"> and C<@v> to C<(1,2,3)>.	
 
 =item C<BROKEN>
 
@@ -1111,13 +1084,13 @@ If any of the program fragments fails to compile or aborts for any
 reason, and you have set the C<BROKEN> option to a function reference,
 C<Text::Template> will invoke the function.  This function is called
 the I<C<BROKEN> function>.  The C<BROKEN> function will tell
-C<Text::Template> what to do next.
+C<Text::Template> what to do next.  
 
 If the C<BROKEN> function returns C<undef>, C<Text::Template> will
 immediately abort processing the template and return the text that it
 has accumulated so far.  If your function does this, it should set a
 flag that you can examine after C<fill_in> returns so that you can
-tell whether there was a premature return or not.
+tell whether there was a premature return or not. 
 
 If the C<BROKEN> function returns any other value, that value will be
 interpolated into the template as if that value had been the return
@@ -1179,7 +1152,7 @@ If you supply the C<BROKEN_ARG> option to C<fill_in>, the value of the
 option is passed to the C<BROKEN> function whenever it is called.  The
 default C<BROKEN> function ignores the C<BROKEN_ARG>, but you can
 write a custom C<BROKEN> function that uses the C<BROKEN_ARG> to get
-more information about what went wrong.
+more information about what went wrong. 
 
 The C<BROKEN> function could also use the C<BROKEN_ARG> as a reference
 to store an error message or some other information that it wants to
@@ -1187,7 +1160,7 @@ communicate back to the caller.  For example:
 
 	$error = '';
 
-	sub my_broken {
+	sub my_broken {	
 	   my %args = @_;
 	   my $err_ref = $args{arg};
 	   ...
@@ -1220,7 +1193,7 @@ operations that can be performed in them.
 
 If you use the C<PACKAGE> option with C<SAFE>, the package you specify
 will be placed into the safe compartment and evaluation will take
-place in that package as usual.
+place in that package as usual.  
 
 If not, C<SAFE> operation is a little different from the default.
 Usually, if you don't specify a package, evaluation of program
@@ -1264,11 +1237,11 @@ If this option is present, its value should be a reference to a list
 of two strings.  The first string is the string that signals the
 beginning of each program fragment, and the second string is the
 string that signals the end of each program fragment.  See
-L<"Alternative Delimiters">, below.
+L<"Alternative Delimiters">, below.  
 
 If you specify C<DELIMITERS> in the call to C<fill_in>, they override
 any delimiters you set when you created the template object with
-C<new>.
+C<new>. 
 
 =back
 
@@ -1276,34 +1249,26 @@ C<new>.
 
 =head2 C<fill_this_in>
 
-C<fill_this_in> was deprecated in the previous version of
-Text::Template and has been deleted in the current version.  As
-recommended in the previous version, use C<fill_in_string> instead.
-
-=head2 C<fill_in_string>
-
 The basic way to fill in a template is to create a template object and
 then call C<fill_in> on it.   This is useful if you want to fill in
 the same template more than once.
 
-In some programs, this can be cumbersome.  C<fill_in_string> is a 
-publicly callable function which accepts (a) a string containing the 
-template, and (b) a list of options which are passed to C<fill_in> as 
-above.  It constructs the template object for you, fills it in as 
-specified, and returns the results.  It returns C<undef> and sets 
-C<$Text::Template::ERROR> if it couldn't generate any results.
+In some programs, this can be cumbersome.  C<fill_this_in> accepts a
+string, which contains the template, and a list of options, which are
+passed to C<fill_in> as above.  It constructs the template object for
+you, fills it in as specified, and returns the results.  It returns
+C<undef> and sets C<$Text::Template::ERROR> if it couldn't generate
+any results.
 
 An example:
 
-	use Text::Template 'fill_in_string';
-
 	$Q::name = 'Donald';
 	$Q::amount = 141.61;
 	$Q::part = 'hyoid bone';
 
-	print fill_in_string( <<'EOM', PACKAGE => 'Q');
+	$text = Text::Template->fill_this_in( <<'EOM', PACKAGE => Q);
 	Dear {$name},
-	You owe me ${sprintf('%.2f', $amount)}.  
+	You owe me \\${sprintf('%.2f', $amount)}.  
 	Pay or I will break your {$part}.
 		Love,
 		Grand Vizopteryx of Irkutsk.
@@ -1312,6 +1277,33 @@ An example:
 Notice how we included the template in-line in the program by using a
 `here document' with the C<E<lt>E<lt>> notation.
 
+C<fill_this_in> is a deprecated feature.  It is only here for
+backwards compatibility, and may be removed in some far-future version
+in C<Text::Template>.  You should use C<fill_in_string> instead.  It
+is described in the next section.
+
+=head2 C<fill_in_string>
+
+It is stupid that C<fill_this_in> is a class method.  It should have
+been just an imported function, so that you could omit the
+C<Text::Template-E<gt>> in the example above.  But I made the mistake
+four years ago and it is too late to change it.
+
+C<fill_in_string> is exactly like C<fill_this_in> except that it is
+not a method and you can omit the C<Text::Template-E<gt>> and just say
+
+	print fill_in_string(<<'EOM', ...);
+	Dear {$name},
+	  ...
+	EOM
+
+To use C<fill_in_string>, you need to say
+
+	use Text::Template 'fill_in_string';
+
+at the top of your program.   You should probably use
+C<fill_in_string> instead of C<fill_this_in>.
+
 =head2 C<fill_in_file>
 
 If you import C<fill_in_file>, you can say
@@ -1381,7 +1373,7 @@ The text C<The King> doesn't get into the form letter.  Why not?
 Because C<$recipient> is a C<my> variable, and the whole point of
 C<my> variables is that they're private and inaccessible except in the
 scope in which they're declared.  The template is not part of that
-scope, so the template can't see C<$recipient>.
+scope, so the template can't see C<$recipient>.  
 
 If that's not the behavior you want, don't use C<my>.  C<my> means a
 private variable, and in this case you don't want the variable to be
@@ -1391,7 +1383,6 @@ package, and use the C<PACKAGE> option to C<fill_in>:
 	$Q::recipient = $recipient;
 	my $text = fill_in_file('formletter.tmpl', PACKAGE => 'Q');
 
-
 or pass the names and values in a hash with the C<HASH> option:
 
 	my $text = fill_in_file('formletter.tmpl', HASH => { recipient => $recipient });
@@ -1407,8 +1398,8 @@ rest of your program and wreck something.
 Nevertheless, there's really no way (except with C<Safe>) to protect
 against a template that says
 
-	{ $Important::Secret::Security::Enable = 0;
-	  # Disable security checks in this program
+	{ $Important::Secret::Security::Enable = 0; 
+	  # Disable security checks in this program 
 	}
 
 or
@@ -1472,13 +1463,12 @@ you may be able to make it work by doing this instead:
 	--@]
 
 It may be safer to choose delimiters that begin with a newline
-character.
+character.  
 
 Because the parsing of templates is simplified by the absence of
-backslash escapes, using alternative C<DELIMITERS> I<speeds up> the
+backslash escapes, using alternative C<DELIMITERS> may speed up the
 parsing process by 20-25%.  This shows that my original choice of C<{>
-and C<}> was very bad.  I therefore recommend that you use alternative
-delimiters whenever possible.
+and C<}> was very bad. 
 
 =head2 C<PREPEND> feature and using C<strict> in templates
 
@@ -1502,12 +1492,12 @@ each and every code fragment:
 
 Because we didn't put C<use strict> at the top of the second fragment,
 it was only active in the first fragment, and we didn't get any
-C<strict> checking in the second fragment.  Then we mispelled C<$foo>
-and the error wasn't caught.
+C<strict> checking in the second fragment.  Then we misspelled C<$foo>
+and the error wasn't caught.  
 
 C<Text::Template> version 1.22 and higher has a new feature to make
 this easier.  You can specify that any text at all be automatically
-added to the beginning of each program fragment.
+added to the beginning of each program fragment.  
 
 When you make a call to C<fill_in>, you can specify a
 
@@ -1545,14 +1535,14 @@ template.  Finally, you can make the class method call
 
 	Text::Template->always_prepend('perl statements');
 
-If you do this, then all calls to C<fill_in> for I<any> template will
+If you do this, then call calls to C<fill_in> for I<any> template will
 attach the perl statements to the beginning of each program fragment,
 except where overridden by C<PREPEND> options to C<new> or C<fill_in>.
 
 =head2 Prepending in Derived Classes
 
 This section is technical, and you should skip it on the first few
-readings.
+readings. 
 
 Normally there are three places that prepended text could come from.
 It could come from the C<PREPEND> option in the C<fill_in> call, from
@@ -1562,12 +1552,12 @@ C<Text::Template> looks for these three things in order and takes the
 first one that it finds.
 
 In a subclass of C<Text::Template>, this last possibility is
-ambiguous.  Suppose C<S> is a subclass of C<Text::Template>.  Should
+ambiguous.  Suppose C<S> is a subclass of C<Text::Template>.  Should 
 
 	Text::Template->always_prepend(...);
 
 affect objects in class C<Derived>?  The answer is that you can have it
-either way.
+either way.  
 
 The C<always_prepend> value for C<Text::Template> is normally stored
 in  a hash variable named C<%GLOBAL_PREPEND> under the key
@@ -1598,7 +1588,7 @@ method to get an arbitrary effect.
 Jennifer D. St Clair asks:
 
 	> Most of my pages contain JavaScript and Stylesheets.
-        > How do I change the template identifier?
+        > How do I change the template identifier?  
 
 Jennifer is worried about the braces in the JavaScript being taken as
 the delimiters of the Perl program fragments.  Of course, disaster
@@ -1611,13 +1601,13 @@ some reason, there are  two easy workarounds:
 1. You can put C<\> in front of C<{>, C<}>, or C<\> to remove its
 special meaning.  So, for example, instead of
 
-	    if (br== "n3") {
+	    if (br== "n3") { 
 		// etc.
 	    }
 
 you can put
 
-	    if (br== "n3") \{
+	    if (br== "n3") \{ 
 		// etc.
 	    \}
 
@@ -1638,26 +1628,25 @@ So if we wrote
 
 	    {q{foo}}
 
-it would turn into
+it would turn into 
 
 	    foo
 
 So for your JavaScript, just write
 
-	    {q{if (br== "n3") {
+	    {q{if (br== "n3") { 
 	  	 // etc.
 	       }}
 	    }
 
 and it'll come out as
 
-	      if (br== "n3") {
+	      if (br== "n3") { 
 	  	  // etc.
 	      }
 
 which is what you want.
 
-
 =head2 Shut Up!
 
 People sometimes try to put an initialization section at the top of
@@ -1668,7 +1657,7 @@ their templates, like this:
 	}
 
 Then they complain because there is a C<17> at the top of the output
-that they didn't want to have there.
+that they didn't want to have there.  
 
 Remember that a program fragment is replaced with its own return
 value, and that in Perl the return value of a code block is the value
@@ -1734,18 +1723,17 @@ complicated to remember, but probably easier to use.  The rule is now:
 Backslashes are always passed to Perl unchanged I<unless> they occur
 as part of a sequence like C<\\\\\\{> or C<\\\\\\}>.  In these
 contexts, they are special; C<\\> is replaced with C<\>, and C<\{> and
-C<\}> signal a literal brace.
+C<\}> signal a literal brace. 
 
 Examples:
 
 	\{ foo \}
 
 is I<not> evaluated, because the C<\> before the braces signals that
-they should be taken literally.  The result in the output looks like this:
+they should be taken literally.  The result in the output looks like this: 
 
 	{ foo }
 
-
 This is a syntax error:
 
 	{ "foo}" }
@@ -1819,52 +1807,27 @@ inside the template:
 It may be useful to preprocess the program fragments before they are
 evaluated.  See C<Text::Template::Preprocess> for more details.
 
-=head2 Author
+=head2 Automatic postprocessing of template hunks
 
-Mark-Jason Dominus, Plover Systems
+It may be useful to process hunks of output before they are appended to
+the result text.  For this, subclass and replace the C<append_text_to_result>
+method.  It is passed a list of pairs with these entries:
 
-Please send questions and other remarks about this software to
-C<mjd-perl-template+@plover.com>
+  handle - a filehandle to which to print the desired output
+  out    - a ref to a string to which to append, to use if handle is not given
+  text   - the text that will be appended
+  type   - where the text came from: TEXT for literal text, PROG for code
 
-You can join a very low-volume (E<lt>10 messages per year) mailing
-list for announcements about this package.  Send an empty note to
-C<mjd-perl-template-request@plover.com> to join.
-
-For updates, visit C<http://www.plover.com/~mjd/perl/Template/>.
-
-=head2 Support?
-
-This software is version 1.45.  It may have bugs.  Suggestions and bug
-reports are always welcome.  Send them to
-C<mjd-perl-template+@plover.com>.  (That is my address, not the address
-of the mailing list.  The mailing list address is a secret.)
-
-=head1 LICENSE
-
-    Text::Template version 1.45
-    Copyright (C) 2003 Mark Jason Dominus
-
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public License as
-    published by the Free Software Foundation; either version 2 of the
-    License, or (at your option) any later version.  You may also can
-    redistribute it and/or modify it under the terms of the Perl
-    Artistic License.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received copies of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+=head1 SUPPORT
 
+This software may have bugs.  Suggestions and bug reports are always welcome.
+Send them to C<mjd-perl-template+@plover.com>.  (That is my address, not the
+address of the mailing list.  The mailing list address is a secret.)
 
 =head1 THANKS
 
 Many thanks to the following people for offering support,
-encouragement, advice, bug reports, and all the other good stuff.
+encouragement, advice, bug reports, and all the other good stuff.  
 
 David H. Adler /
 Joel Appelbaum /
@@ -1895,7 +1858,7 @@ Matt X. Hunter /
 Robert M. Ioffe /
 Daniel LaLiberte /
 Reuven M. Lerner /
-Trip Lilley /
+Trip Lilley / 
 Yannis Livassof /
 Val Luck /
 Kevin Madsen /
@@ -1941,12 +1904,12 @@ Special thanks to:
 
 =over 2
 
-=item Jonathan Roy
+=item Jonathan Roy 
 
 for telling me how to do the C<Safe> support (I spent two years
 worrying about it, and then Jonathan pointed out that it was trivial.)
 
-=item Ranjit Bhatnagar
+=item Ranjit Bhatnagar 
 
 for demanding less verbose fragments like they have in ASP, for
 helping me figure out the Right Thing, and, especially, for talking me
@@ -1970,5 +1933,34 @@ use it as if it were a regular variable.
 
 There are not quite enough tests in the test suite.
 
-=cut
+=head1 SOURCE
 
+The development version is on github at L<http://github.com/mschout/perl-text-template>
+and may be cloned from L<git://github.com/mschout/perl-text-template.git>
+
+=head1 BUGS
+
+Please report any bugs or feature requests to bug-text-template@rt.cpan.org or through the web interface at:
+ http://rt.cpan.org/Public/Dist/Display.html?Name=Text-Template
+
+=head1 AUTHOR
+
+Mark Jason Dominus, Plover Systems
+
+Please send questions and other remarks about this software to
+C<mjd-perl-template+@plover.com>
+
+You can join a very low-volume (E<lt>10 messages per year) mailing
+list for announcements about this package.  Send an empty note to
+C<mjd-perl-template-request@plover.com> to join.
+
+For updates, visit C<http://www.plover.com/~mjd/perl/Template/>.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2013 by Mark Jason Dominus <mjd@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
